/**
 * Arduino Mega with RAMPS v1.3 pin assignments
 *
 * Applies to the following boards:
 *
 *  RAMPS_13_EFB (Extruder, Fan, Bed)
 *  RAMPS_13_EEB (Extruder, Extruder, Bed)
 *  RAMPS_13_EFF (Extruder, Fan, Fan)
 *  RAMPS_13_EEF (Extruder, Extruder, Fan)
 *
 *  Other pins_MYBOARD.h files may override these defaults
 */

#if !defined(__AVR_ATmega1280__) && !defined(__AVR_ATmega2560__)
  #error Oops!  Make sure you have 'Arduino Mega' selected from the 'Tools -> Boards' menu.
#endif

#define LARGE_FLASH true

#define X_STEP_PIN         25
#define X_DIR_PIN          23
#define X_ENABLE_PIN       27
#define X_MIN_PIN          22
#define X_MAX_PIN          24

#define Y_STEP_PIN         31
#define Y_DIR_PIN          33
#define Y_ENABLE_PIN       29
#define Y_MIN_PIN          26
#define Y_MAX_PIN          28

#define Z_STEP_PIN         37
#define Z_DIR_PIN          39
#define Z_ENABLE_PIN       35
#define Z_MIN_PIN          30
#define Z_MAX_PIN          32
#define Z_PROBE_PIN        -1///////////////////////////////////////////////////////////////////////////////////////

#define E0_STEP_PIN        43
#define E0_DIR_PIN         45
#define E0_ENABLE_PIN      41

#define E1_STEP_PIN        49
#define E1_DIR_PIN         47
#define E1_ENABLE_PIN      48

#define E2_STEP_PIN        44
#define E2_DIR_PIN         46
#define E2_ENABLE_PIN      36

#define SDPOWER            -1
#define SDSS               53
#define LED_PIN            13
#define PS_ON_PIN          -1

#if MB(RAMPS_13_EEB) && defined(FILAMENT_SENSOR)  // FMM added for Filament Extruder
  // define analog pin for the filament width sensor input
  // Use the RAMPS 1.4 Analog input 5 on the AUX2 connector
  #define FILWIDTH_PIN        5
#endif

#ifdef FILAMENT_RUNOUT_SENSOR
  // define digital pin 4 for the filament runout sensor. Use the RAMPS 1.4 digital input 4 on the servos connector
  #define FILRUNOUT_PIN        34
#endif

#define FAN_PIN            7

#define HEATER_0_PIN       2   // EXTRUDER 1
#define HEATER_1_PIN       3    // EXTRUDER 2 (FAN On Sprinter)
#define HEATER_2_PIN       8

#define TEMP_0_PIN         8   // ANALOG NUMBERING
#define TEMP_1_PIN         9   // ANALOG NUMBERING
#define TEMP_2_PIN         11   // ANALOG NUMBERING

#define HEATER_BED_PIN     4    // BED
#define TEMP_BED_PIN       10   // ANALOG NUMBERING

#ifdef NUM_SERVOS
  #define SERVO0_PIN         11
  #if NUM_SERVOS > 1
    #define SERVO1_PIN        10
    #if NUM_SERVOS > 2
      #define SERVO2_PIN      9
    #endif
  #endif
#endif





#ifdef ULTRA_LCD

  #ifdef REPRAP_DISCOUNT_SMART_CONTROLLER
      #define LCD_PINS_RS 20
      #define LCD_PINS_ENABLE 17
      #define LCD_PINS_D4 16
      #define LCD_PINS_D5 21
      #define LCD_PINS_D6 5
      #define LCD_PINS_D7 6
      
      #define BEEPER 18
      
      #define BTN_EN1 42
      #define BTN_EN2 40
      #define BTN_ENC 19
      
      #define SDCARDDETECT 38
    #endif
#endif // ULTRA_LCD

#ifndef SDSUPPORT
  // these pins are defined in the SD library if building with SD support
  #define SCK_PIN          52
  #define MISO_PIN         50
  #define MOSI_PIN         51
#endif
